@@ -289,7 +289,7 @@ class TransformerRETextClassificationTaskModule(_TransformerReTextClassification
 
         for document in documents:
             entities = document.annotations.spans[self.entity_annotation]
-            if document.annotations.binary_relations.has_layer(self.relation_annotation):
+            if is_training:
                 relations = document.annotations.binary_relations[self.relation_annotation]
             else:
                 relations = None
